// #![allow(dead_code)]

pub mod aa_tree;
pub mod abstract_structs;
pub mod argsort;
pub mod array_compression;
pub mod binary_search;
pub mod bitwise;
pub mod carmichael_number;
pub mod chinese_remainder_theorem;
pub mod cmp;
pub mod combinatorics;
pub mod division;
pub mod divisor;
pub mod euclidean;
pub mod fenwick_tree;
pub mod fenwick_tree_dual;
pub mod graph;
pub mod graph_pointer_directed;
pub mod graph_pointer_mixed;
pub mod graph_pointer_undirected;
pub mod graph_trait_pointer_mixed;
pub mod group_theory;
pub mod group_theory_preset;
pub mod longest_common_prefix;
pub mod longest_increasing_sequence;
pub mod matrix;
pub mod matrix_constant;
pub mod matrix_dynamic;
pub mod matrix_runtime_static;
pub mod matrix_static;
pub mod modular_constant;
pub mod modular_runtime_static;
pub mod modular_static;
pub mod power;
pub mod primality;
pub mod primality_test_fermat;
pub mod primality_test_miller_rabin;
pub mod prime_number;
pub mod segment_tree;
pub mod segment_tree_dynamic;
pub mod sieve_of_eratosthenes;
pub mod sort;
pub mod sparse_table;
pub mod sparse_table_dynamic;
pub mod string;
pub mod suffix_array;
pub mod tensor;
pub mod union_find;
pub mod union_find_potential;
pub mod vector_util;
